aboutsummaryrefslogtreecommitdiffstats
path: root/frontend/src/components/FeedItems.tsx
diff options
context:
space:
mode:
Diffstat (limited to 'frontend/src/components/FeedItems.tsx')
-rw-r--r--frontend/src/components/FeedItems.tsx4
1 files changed, 2 insertions, 2 deletions
diff --git a/frontend/src/components/FeedItems.tsx b/frontend/src/components/FeedItems.tsx
index e2df011..e38850a 100644
--- a/frontend/src/components/FeedItems.tsx
+++ b/frontend/src/components/FeedItems.tsx
@@ -216,8 +216,8 @@ export default function FeedItems() {
const rect = el.getBoundingClientRect();
- // Mark as read if the top of the item is above the top of the container
- if (rect.top < containerRect.top) {
+ // Mark as read if the bottom of the item is above the top of the container
+ if (rect.bottom < containerRect.top) {
markAsRead(item);
}
});